==> sportsdata-0.0.29.tar.gz: sportsdata-0.0.29/README.md <==
# sportsdata

Collection of sports data objects, APIs, Website (data), and factual data for each sport such as teams, rosters, etc. 
The goal is to integrate both my own work and any relevant eligible libraries that are on GitHub. Collaboration on this 
project is definitely hoped for. 

*Currently this library includes:*
* API for NBA

### Installing sportsdata
sportsdata can be installed via pip. 
```bash
pip install sportsdata
```

### Installing

A step by step series of examples that tell you how to get a development env running

Say what the step will be

```
Give the example
```

And repeat

```
until finished
```

End with an example of getting some data out of the system or using it for a little demo

## Running the Tests

Explain how to run the automated tests for this system

### Break down into end to end tests

Explain what these tests test and why

```
Give an example
```

### And coding style tests

Explain what these tests test and why

```
Give an example
```

## Deployment

Add additional notes about how to deploy this on a live system

## Built With

* [Dropwizard](http://www.dropwizard.io/1.0.2/docs/) - The web framework used

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 

## Authors
 **David Orkin** - *First Draft* - [OrangeCardinal](https://github.com/OrangeCardinal)

See also the list of [contributors](https://github.com/your/project/contributors) who participated in this project.

## License

This project is licensed under the Apache License 2.0 - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments
These are the various sources referenced while building this library



| URL        | Note           |
| ------------- |:-------------:|
| https://github.com/bradleyfay/py-Goldsberry | NBA Api Reference.  |
| https://github.com/roclark/sportsipy     | nba.teams,        |






* Thanks for the README.md template from  **Billie Thompson** [PurpleBooth](https://github.com/PurpleBooth)!



**Major League Baseball Data**
Major league baseball offers various API endpoints. 

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

==> sportsdata-0.0.39.tar.gz: sportsdata-0.0.39/README.md <==
# sportsdata

Collection of sports data objects, APIs, Website (data), and factual data for each sport such as teams, rosters, etc. 
The goal is to integrate both my own work and any relevant eligible libraries that are on GitHub. Collaboration on this 
project is definitely hoped for. 

*Currently this library includes:*
* An API for stats.nba.com

### Installing sportsdata
sportsdata can be installed via pip. 
```bash
pip install sportsdata
```

### Break down into end to end tests

Explain what these tests test and why

```
Give an example
```

### Coding Style Guidelines

This repository attempts to be PEP compliant in regards to code style and any submitted code should be 
formatted accordingly 

## Deployment

Add additional notes about how to deploy this on a live system

## Built With

* [Dropwizard](http://www.dropwizard.io/1.0.2/docs/) - The web framework used

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 

## Authors
 **David Orkin** - *First Draft* - [OrangeCardinal](https://github.com/OrangeCardinal)

See also the list of [contributors](https://github.com/your/project/contributors) who participated in this project.

## License

This project is licensed under the Apache License 2.0 - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments
These are the various sources referenced while building this library



| URL        | Note           |
| ------------- |:-------------:|
| https://github.com/bradleyfay/py-Goldsberry | NBA Api Reference.  |
| https://github.com/roclark/sportsipy     | nba.teams,        |






* Thanks for the README.md template from  **Billie Thompson** [PurpleBooth](https://github.com/PurpleBooth)!



**Major League Baseball Data**
Major league baseball offers various API endpoints. 

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.
